@@ -1,4 +1,4 @@
-# $Id: autogen.sh,v 1.1 2003/03/12 02:01:16 jday Exp $
+# $Id: autogen.sh,v 1.1.1.3 2004/01/30 08:04:33 rousseau Exp $
 
 set -x
 
@@ -9,5 +9,5 @@ libtoolize --force --copy
 
 autoheader
 automake --add-missing --foreign
-autoconf2.50
+autoconf
 
